@@ -45,7 +45,7 @@ except ImportError:
 try:
     from ._version import version as __version__
 except ImportError:
-    __version__ = '3.3.2'
+    __version__ = '3.3.6'
 
 __all__ = (
     'And',
@@ -64,7 +64,6 @@ __all__ = (
     'VarsPrinter',
     'VarsSnooper',
     'When',
-    'Backlog',
 
     'stop',
     'trace',
@@ -84,6 +83,32 @@ _default_config = {}
 _default_stream = sys.stderr
 
 
+def _embed_via_environment():
+    if 'PYTHONHUNTER' in os.environ:
+        try:
+            eval('trace({[PYTHONHUNTER]})'.format(os.environ), {
+                'And': And,
+                'Backlog': Backlog,
+                'CallPrinter': CallPrinter,
+                'CodePrinter': CodePrinter,
+                'Debugger': Debugger,
+                'ErrorSnooper': ErrorSnooper,
+                'From': From,
+                'Manhole': Manhole,
+                'Not': Not,
+                'Or': Or,
+                'Q': Q,
+                'Query': Query,
+                'StackPrinter': StackPrinter,
+                'VarsPrinter': VarsPrinter,
+                'VarsSnooper': VarsSnooper,
+                'When': When,
+                'trace': trace,
+            })
+        except Exception as exc:
+            sys.stderr.write('Failed to load hunter from PYTHONHUNTER environ variable {[PYTHONHUNTER]!r}: {!r}\n'.format(os.environ, exc))
+
+
 def _prepare_config(*args, **kwargs):
     _default_config.clear()
     _default_config.update((key.lower(), val) for key, val in kwargs.items())
